@@ -96,6 +96,10 @@ mod tests {
         Rule::InvalidCharacterZeroWidthSpace,
         Path::new("invalid_characters.py")
     )]
+    #[test_case(
+        Rule::InvalidCharacterBackspace,
+        Path::new("invalid_characters_syntax_error.py")
+    )]
     #[test_case(Rule::InvalidEnvvarDefault, Path::new("invalid_envvar_default.py"))]
     #[test_case(Rule::InvalidEnvvarValue, Path::new("invalid_envvar_value.py"))]
     #[test_case(Rule::IterationOverSet, Path::new("iteration_over_set.py"))]
