@@ -1,5 +1,6 @@
 use ruff_diagnostics::{Diagnostic, Edit, Fix, FixAvailability, Violation};
 use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::name::Name;
 use ruff_python_ast::{self as ast, Expr};
 use ruff_python_semantic::analyze::typing::is_mutable_expr;
 
@@ -99,7 +100,7 @@ pub(crate) fn mutable_fromkeys_value(checker: &mut Checker, call: &ast::ExprCall
 fn generate_dict_comprehension(keys: &Expr, value: &Expr, generator: Generator) -> String {
     // Construct `key`.
     let key = ast::ExprName {
-        id: "key".to_string(),
+        id: Name::new_static("key"),
         ctx: ast::ExprContext::Load,
         range: TextRange::default(),
     };
